// Framework to hold Arduino Nano. Made to be incorporated into devices.
// Make sure the opening for the USB connector is accessible!

// nano_holder makes the whole holder. nano_holder_left and _right make the
// left and right halves, respectively. The holder must be split in some
// manner so that the Nano can be inserted.

// Part of the components library.

// By Nenad Rijavec
// Feel free to use, share, modify, etc. as you see fit.

nano_w = 18 + 1 ; // add a bit extra
nano_l = 43.5 + 1 ; // add a bit extra
nano_board_h = 2.5 ;
do_build = 0 ;
h_below = 2 ;
h_above = -6 ;

module nano_mockup()
{

	// PCB
	cube( [ nano_l, nano_w, nano_board_h ] ) ;
	// top connectors
	translate( [ 2.5, 0, 0 ] )
		cube( [ nano_l-5, nano_w, nano_board_h+8.5 ] ) ;
	// bottom protrusions from the top
	translate( [ 2.5, 0, -2 ] )
		cube( [ nano_l-5, 3, 3 ] ) ;
	translate( [ 2.5, nano_w-3, -2 ] )
		cube( [ nano_l-5, 3, 3 ] ) ;
	// bottom connectors
	translate( [ 0, (nano_w-3*2.54)/2, -8.5 ] )
		cube( [ 2*2.54, 3*2.54, nano_board_h+8.5 ] ) ;
	// USB
	translate( [ nano_l-8, (nano_w-8.5)/2, -4.5 ] )
		cube( [ 10.1, 8.5, 4.71 ] ) ;
}

module nano_holder( h_below, h_above)
{
	hh = h_below+h_above+nano_board_h + 4 + 8.5 ;
	board_offset = 4 + h_below ;
	difference() {
		union() {
			cube( [ 4, 4, hh ] ) ;
			translate( [ 0, nano_w, 0 ] ) cube( [ 4, 4, hh ] ) ;
			translate( [ nano_l, 0, 0 ] ) cube( [ 4, 4, hh ] ) ;
			translate( [ nano_l, nano_w, 0 ] )
				cube( [ 4, 4, hh ] ) ;
			cube( [ nano_l+4, 2, 6 ] ) ;
			translate( [ 0, 0, hh-4 ] )
				cube( [ nano_l+4, 2, 4 ] ) ;
			translate( [ 0, nano_w+2, 0 ] )
				cube( [ nano_l+4, 2, 6 ] ) ;
			translate( [ 0, nano_w+2, hh-4 ] )
				cube( [ nano_l+4, 2, 4 ] ) ;
			cube( [2, nano_w+4, hh ] ) ;
			translate( [ nano_l+2, 0, 0 ] )
				cube( [2, nano_w+4, hh ] ) ;
		}
		translate( [ 2.0, 2.0, board_offset ] ) nano_mockup() ;
	}
}

module nano_holder_left( h_below, h_above)
{
	intersection() {
		nano_holder( h_below, h_above) ;
		translate( [ -1, -1, -1 ] ) cube( [ 200, 3+nano_w/2, 200 ] )
		;
	}
}

module nano_holder_right( h_below, h_above)
{
	intersection() {
		nano_holder( h_below, h_above) ;
		translate( [ -1, 2+nano_w/2, -1 ] ) cube( [ 200, 3+nano_w/2, 200 ] )
		;
	}
}

if  ( do_build ) {
	rotate( [ 90, 0, 0 ] ) 
		nano_holder_left( h_below, h_above) ;
	translate( [ 0, 10, 2+nano_w/2] )
	rotate( [ -90, 0, 0 ] ) translate( [ 0, -2-nano_w/2, 0 ] )
	nano_holder_right( h_below, h_above) ;
} else {
	
	translate( [ 2, 2, h_below+4 ] ) nano_mockup() ;
	nano_holder_left( h_below, h_above) ;
	translate( [ 0, 0, 0] ) nano_holder_right( h_below, h_above) ;
}


// nenad me fecit
